Class SpelParserConfiguration

java.lang.Object
org.springframework.expression.spel.SpelParserConfiguration

public class SpelParserConfiguration extends Object
Configuration object for the SpEL expression parser.
Since:
3.0
Author:
Juergen Hoeller, Phillip Webb, Andy Clement, Sam Brannen
See Also:
  • Field Details

    • DEFAULT_MAX_EXPRESSION_LENGTH

      public static final int DEFAULT_MAX_EXPRESSION_LENGTH
      Default maximum length permitted for a SpEL expression: 10000.
      Since:
      5.2.24
      See Also:
    • DEFAULT_MAX_OPERATIONS

      public static final int DEFAULT_MAX_OPERATIONS
      Default maximum number of operations permitted during SpEL expression evaluation: 10000.
      Since:
      6.2.19
      See Also:
    • SPRING_EXPRESSION_COMPILER_MODE_PROPERTY_NAME

      public static final String SPRING_EXPRESSION_COMPILER_MODE_PROPERTY_NAME
      System property to configure the default compiler mode for SpEL expression parsers: "spring.expression.compiler.mode".

      NOTE: Instead of relying on a global default, applications and frameworks should ideally set an explicit custom value via the SpelParserConfiguration(SpelCompilerMode, ClassLoader, boolean, boolean, int, int, int) constructor which provides complete configuration control and the ability to override global defaults per use case.

      Can also be configured via the SpringProperties mechanism.

      See Also:
    • SPRING_EXPRESSION_MAX_OPERATIONS_PROPERTY_NAME

      public static final String SPRING_EXPRESSION_MAX_OPERATIONS_PROPERTY_NAME
      System property to configure the default maximum number of operations permitted during SpEL expression evaluation: "spring.expression.maxOperations".

      NOTE: Instead of relying on a global default, applications and frameworks should ideally set an explicit custom value via the SpelParserConfiguration(SpelCompilerMode, ClassLoader, boolean, boolean, int, int, int) constructor which provides complete configuration control and the ability to override global defaults per use case.

      Can also be configured via the SpringProperties mechanism.

      Since:
      6.2.19
      See Also:
  • Constructor Details

  • Method Details

    • getCompilerMode

      public SpelCompilerMode getCompilerMode()
      Return the compiler mode for parsers using this configuration object.
    • getCompilerClassLoader

      @Nullable public ClassLoader getCompilerClassLoader()
      Return the ClassLoader to use as the basis for expression compilation.
    • isAutoGrowNullReferences

      public boolean isAutoGrowNullReferences()
      Return true if null references should be automatically grown.
    • isAutoGrowCollections

      public boolean isAutoGrowCollections()
      Return true if collections should be automatically grown.
    • getMaximumAutoGrowSize

      public int getMaximumAutoGrowSize()
      Return the maximum size to which a collection can auto grow.
    • getMaximumExpressionLength

      public int getMaximumExpressionLength()
      Return the maximum number of characters that a SpEL expression can contain.
      Since:
      5.2.25
    • getMaximumOperations

      public int getMaximumOperations()
      Return the maximum number of operations permitted during SpEL expression evaluation.
      Since:
      6.2.19